<?php
/**
 * Name         : Elementor Addons For Maxhost
 * Description  : Provides additional Elementor Elements for the Maxhost theme
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

final class Maxhost_Elementor_Extensions {

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var Maxhost_Elementor_Extensions The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return Maxhost_Elementor_Extensions An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {

		add_action( 'plugins_loaded', [ $this, 'init' ] );

	}

	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

			// Add Plugin actions
			add_action( 'elementor/elements/categories_registered', array( $this, 'add_widget_categories' ) );
			add_action( 'elementor/widgets/widgets_registered', [ $this, 'init_widgets' ] );
			add_action( 'elementor/preview/enqueue_styles', [ $this, 'custom_styles' ] );
	}

	
	/**
     * Element Category Register
     */
    public function add_widget_categories( $elements_manager ) {
        $elements_manager->add_category(
            'maxhost-elements',
            [
                'title' => esc_html__( 'Maxhost Elements', 'maxhost' ),
                'icon' => 'fa fa-plug',
            ]
        );
    }
	
	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init_widgets() {

		// Include Widget files
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/accor_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/accor_02.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/accor_03.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/accor_04.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/blog_posts_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/blog_posts_02.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/bullet_points.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/call_to_action.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/clients_block.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/domain_package.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/domain_register.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/domain_search.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_block_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_block_05.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_block_06.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_table.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_with_icons_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_with_icons_02.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_with_icons_03.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_with_icons_04.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_with_icons_05.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_with_icons_06.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/features_with_icons_07.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/horizontal_tabs_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/horizontal_tabs_02.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/mega_menu_01.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/offers_carousel.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/page_header.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/pricing_filter.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/pricing_table_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/pricing_table_02.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/pricing_table_03.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/pricing_table_04.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/team.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/testimonial_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/testimonial_02.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/testimonial_03.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/testimonial_04.php';
		
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_01.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_02.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_03.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_04.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_05.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_06.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_07.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_08.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/title_09.php';
		require_once MAXHOST_PLUGIN_PATH . '/modules/elementor/elements/top_heading_section.php';

		// Register widget
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Accor_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Accor_02() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Accor_03() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Accor_04() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Blog_Posts_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Blog_Posts_02() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Bullet_Points() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Call_To_Action() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Clients_Block() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Domain_Package() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Domains_Register() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Domain_Search() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Features_Block_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Features_Block_05() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Features_Block_06() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Features_Table() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Iconic_Features_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Iconic_Features_02() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Iconic_Features_03() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Iconic_Features_04() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Iconic_Features_05() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Iconic_Features_06() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Iconic_Features_07() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Htab_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Htab_02() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Mega_Menu_01() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Offers_Carousel() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Page_Header() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Pricing_Filter() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Pricing_Table_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Pricing_Table_02() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Pricing_Table_03() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Pricing_Table_04() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Team() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Testimoni_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Testimoni_02() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Testimoni_03() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Testimoni_04() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_01() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_02() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_03() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_04() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_05() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_06() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_07() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_08() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Title_09() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Maxhost_Elementor_Top_Heading_Section() );

	}
	
	public function custom_styles() { ?>
		<style id="maxhost_elementor_admin_custom_style">
		.elementor-editor-active div#preloader {display: none !important;}
		</style>
		<?php
    }

}

if ( did_action( 'elementor/loaded' ) ) {
    Maxhost_Elementor_Extensions::instance();
}